@@ -58,12 +58,13 @@ use v5.40;
 #
 
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 use Daje::Database::Model::ToolsProjects;
 use Daje::Database::Helper::TreeList;
 use Daje::Database::View::VToolsProjects;
 use Daje::Database::View::VToolsVersion;
+use Daje::Database::Model::ToolsVersion;
 use Daje::Database::Model::ToolsObjectsTables;
 use Daje::Database::Model::ToolsObjectsTablesDatatypes;
 use Daje::Database::Model::ToolsObjects;
@@ -105,6 +106,10 @@ sub register ($self, $app, $config) {
         v_tools_versions => sub {
             state  $v_tools_versions = Daje::Database::View::VToolsVersion->new(db => shift->pg->db)
         });
+    $app->helper(
+        tools_versions => sub {
+            state  $tools_versions = Daje::Database::Model::ToolsVersion->new(db => shift->pg->db)
+        });
     $app->helper(
         tools_objects_tables => sub {
             state  $tools_objects_tables = Daje::Database::Model::ToolsObjectsTables->new(db => shift->pg->db)
@@ -148,6 +153,7 @@ sub register ($self, $app, $config) {
     my $r = $app->routes;
     $r->get('/tools/api/v1/projects')->to('ToolsProjects#load_projects');
     $r->get('/tools/api/v1/versions/')->to('ToolsVersions#load_versions_list');
+    $r->get('/tools/api/v1/version/:tools_projects_pkey')->to('ToolsVersions#load_current_version');
     $r->get('/tools/api/v1/versions/:tools_version_pkey')->to('ToolsVersions#load_versions');
     $r->get('/tools/api/v1/treelist/:tools_projects_pkey')->to('ToolsTreelist#load_treelist');
     $r->get('/tools/api/v1/parameters/treelist/')->to('ToolsParameterTreelist#load_treelist');
@@ -329,7 +335,8 @@ ALTER TABLE tools_object_tables
     ADD COLUMN tools_objects_tables_datatypes_fkey BIGINT NOT NULL;
 
 ALTER TABLE tools_object_tables
-      ADD CONSTRAINT tools_object_tables_tools_objects_tables_datatypes_fkey FOREIGN KEY (tools_objects_tables_datatypes_fkey)
+      ADD CONSTRAINT tools_object_tables_tools_objects_tables_datatypes_fkey
+        FOREIGN KEY (tools_objects_tables_datatypes_fkey)
           REFERENCES tools_objects_tables_datatypes (tools_objects_tables_datatypes_pkey);
 
 -- 6 down
